@@ -940,11 +940,11 @@ struct address_info *sockaddr2address_info(size_t addr_len,
 
 		ip = ntohl(in->sin_addr.s_addr);
 		port = ntohs(in->sin_port);
-		a = make_inet_address(c_format("%i.%i.%i.%i%c",
+		a = make_inet_address(c_format_cstring("%i.%i.%i.%i",
 					       (ip >> 24) & 0xff,
 					       (ip >> 16) & 0xff,
 					       (ip >> 8) & 0xff,
-					       ip & 0xff, 0), port);
+					       ip & 0xff), port);
 		memcpy(&a->sa, addr, addr_len);
 		return &a->super;
 	}
@@ -954,10 +954,10 @@ struct address_info *sockaddr2address_info(size_t addr_len,
 	}
 #if 0
 	case AF_INETv6:
-		...
+		break;
 #endif
-		default:
-			fatal("io.c: sockaddr2info(): Unsupported address family.\n");
+	default:
+		fatal("io.c: sockaddr2info(): Unsupported address family %i.\n", addr->sa_family);
 	}
 }
 
@@ -1259,6 +1259,7 @@ void close_fd(struct nonblocking_fd *fd, int reason)
 	debug("Marking fd %i for closing.\n", fd->fd);
 #endif
 	fd->close_reason = reason;
-	fd->to_be_closed = 1;
+	if (!fd->to_be_closed)
+		fd->to_be_closed = 1;
 }
 
